@@ -27,9 +27,10 @@ months    = MonthLocator(1)           # every month
 monthsFmt  = DateFormatter('%b %d')
 
 
-
 quotes = quotes_historical_yahoo(
     'INTC', date1, date2, converter=pydates)
+if not quotes:
+    raise SystemExit
 
 dates = [q[0] for q in quotes]
 opens = [q[1] for q in quotes]
@@ -45,7 +46,7 @@ ax.autoscale_view()
 #ax.xaxis.grid(True, 'minor')
 
 labels = ax.get_xticklabels()
-set(labels, 'rotation', 'vertical')
+set(labels, 'rotation', 45)
 
 grid(True)
 show()
