@@ -24,6 +24,8 @@ dayFormatter = DateFormatter('%d')      # Eg, 12
 
 quotes = quotes_historical_yahoo(
     'INTC', date1, date2, converter)
+if not quotes:
+    raise SystemExit
 
 ax = subplot(111)
 ax.xaxis.set_major_locator(mondays)
@@ -31,8 +33,8 @@ ax.xaxis.set_minor_locator(hours)
 ax.xaxis.set_major_formatter(weekFormatter)
 #ax.xaxis.set_minor_formatter(dayFormatter)
 
-#plot_day_summary(ax, quotes, ticksize=3, converter=converter)
-candlestick(ax, quotes, width=0.6, converter=converter)
+plot_day_summary(ax, quotes, ticksize=3, converter=converter)
+#candlestick(ax, quotes, width=0.6, converter=converter)
 set( gca().get_xticklabels(), 'rotation', 45, 'horizontalalignment', 'right')
 
 show()
