@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 #Controlling the properties of axis text using handles
 
 # See axis_text_themes.py for a more elegant, pythonic way to control
@@ -23,16 +24,16 @@ ttext = title('Fun with text!')
 ytext = ylabel('Damped oscillation')
 xtext = xlabel('time (s)')
 
-set(ttext, 'fontsize', 14)
+set(ttext, 'fontsize', 'large')
 set(ttext, 'color', 'r')
 set(ttext, 'fontangle', 'italic')
 
-set(xtext, 'fontsize', 12)
+set(xtext, 'fontsize', 'medium')
 set(xtext, 'fontname', 'courier')
 set(xtext, 'fontweight', 'bold')
 set(xtext, 'color', 'g')
 
-set(ytext, 'fontsize', 12)
+set(ytext, 'fontsize', 'medium')
 set(ytext, 'fontname', 'helvetica')
 set(ytext, 'fontweight', 'light')
 set(ytext, 'color', 'b')
