@@ -3,7 +3,7 @@ from __future__ import division, generators
 import math, sys
 
 from numerix import MLab, absolute, arange, array, asarray, ones, transpose, \
-     log10, Float, ravel
+     log, log10, Float, ravel
 
 import mlab
 from artist import Artist
@@ -20,7 +20,7 @@ from ticker import YearLocator, MonthLocator, WeekdayLocator, \
      WeekMultiLocator, DayLocator, DayMultiLocator, \
      HourLocator, MinuteLocator, DateFormatter
 from ticker import AutoLocator, LogLocator
-from ticker import ScalarFormatter, LogFormatter
+from ticker import ScalarFormatter, LogFormatter, LogFormatterExponent, LogFormatterMathtext
 
 from image import AxesImage
 from legend import Legend
@@ -38,6 +38,8 @@ from font_manager import FontProperties
 
 # build a string to constants dict for images
 
+
+                     
 def _process_plot_format(fmt):
     """
     Process a matlab style color/line style format string.  Return a
@@ -143,15 +145,17 @@ class _process_plot_var_args:
         assert self.command == 'plot', 'set_lineprops only works with "plot"'
         for key, val in kwargs.items():
             funcName = "set_%s"%key
-            func = getattr(line,funcName)
-            func(val)
+            if hasattr(line,funcName):
+                func = getattr(line,funcName)
+                func(val)
         
     def set_patchprops(self, fill_poly, **kwargs):
         assert self.command == 'fill', 'set_patchprops only works with "fill"'
         for key, val in kwargs.items():
             funcName = "set_%s"%key
-            func = getattr(fill_poly,funcName)
-            func(val)
+            if hasattr(fill_poly,funcName):
+                func = getattr(fill_poly,funcName)
+                func(val)
 
 
     def is_filled(self, marker):
@@ -492,7 +496,7 @@ class Axes(Artist):
         BAR(left, height)
         
         Make a bar plot with rectangles at
-          left, left, 0, height
+          left, left+width, 0, height
         left and height are Numeric arrays
 
         Return value is a list of Rectangle patch instances
@@ -661,7 +665,7 @@ class Axes(Artist):
         self.transAxes.freeze()  # eval the lazy objects
         if self.axison:
             if self._frameon: self._axesPatch.draw(renderer)
-
+            
         if len(self._images)==1:
             im = self._images[0]
             im.draw(renderer)
@@ -718,9 +722,8 @@ class Axes(Artist):
         self.transAxes.thaw()  # release the lazy objects
         renderer.close_group('axes')
 
-
     def errorbar(self, x, y, yerr=None, xerr=None,
-                 fmt='b-', ecolor='k', capsize=3):
+                 fmt='b-', ecolor=None, capsize=3):
         """
         Plot x versus y with error deltas in yerr and xerr.
         Vertical errorbars are plotted if yerr is not None
@@ -738,6 +741,9 @@ class Axes(Artist):
         plot the errorbars with no line symbols.  This can be useful
         for creating a bar plot with errorbars
 
+        ecolor is a matplotlib color arg which gives the color the
+        errobar lines; if None, use the marker color.
+        
         Return value is a length 2 tuple.  The first element is a list of
         y symbol lines.  The second element is a list of error bar lines.
 
@@ -761,34 +767,18 @@ class Axes(Artist):
 
 
         if fmt is not None:
-            l0 = self.plot(x,y,fmt)
+            l0, = self.plot(x,y,fmt)
         else: l0 = None
-        l = []
+        caplines = []
+        barlines = []
 
+        if ecolor is None and l0 is None:
+            ecolor = rcParams['lines.color']
+        elif ecolor is None:
+            ecolor = l0.get_color()
+            
+        capargs = {'c':ecolor, 'mfc':ecolor, 'mec':ecolor, 'ms':2*capsize}
 
-        
-        def get_ybar_cap(x, y):
-            l = Line2D( xdata=(x, x), ydata=(y, y),
-                        color=ecolor,
-                        marker='_',
-                        markersize=2*capsize,
-                        )
-            self._set_artist_props(l)
-            l.set_data_clipping(False)
-            return l
-
-        def get_xbar_cap(x, y):
-            l = Line2D( xdata=(x, x), ydata=(y, y),
-                        color=ecolor,
-                        marker='|',
-                        markersize=2*capsize,
-                        )
-            self._set_artist_props(l)
-            l.set_data_clipping(False)
-            return l
-
-
-        # horizontal errorbars
         if xerr is not None:
             if len(xerr.shape) == 1:
                 left  = x-xerr
@@ -797,26 +787,11 @@ class Axes(Artist):
                 left  = x-xerr[0]
                 right = x+xerr[1]
 
-            # horizontal errorbars
-            hl = self.hlines(y, x, left)
-            for line in hl: line.set_color(ecolor)
-            l.extend( hl )            
+            barlines.extend( self.hlines(y, x, left) )
+            barlines.extend( self.hlines(y, x, right) )            
+            caplines.extend(self.plot(left, y, '|', **capargs))
+            caplines.extend(self.plot(right, y, '|', **capargs))            
 
-
-            hl = self.hlines(y, x, right)
-            for line in hl: line.set_color(ecolor)
-            l.extend( hl )            
-
-            # bar caps
-            for yval, lval, rval in zip(y, left, right):
-                l1 = get_xbar_cap(lval, yval) 
-                l2 = get_xbar_cap(rval, yval) 
-                self.add_line(l1)
-                self.add_line(l2)
-                l.extend( (l1,l2) )
-
-
-        # vertical errorbars
         if yerr is not None:
             if len(yerr.shape) == 1:
                 lower = y-yerr
@@ -825,29 +800,18 @@ class Axes(Artist):
                 lower = y-yerr[0]
                 upper = y+yerr[1]
 
-            # base the bar-end length on the overall horizontal plot dimension
+            barlines.extend( self.vlines(x, y, upper ) )
+            barlines.extend( self.vlines(x, y, lower ) )            
 
-            # vertical errorbars
-            vl = self.vlines(x, y, lower)
-            for line in vl: line.set_color(ecolor)
-            l.extend( vl)
+            caplines.extend(self.plot(x, lower, '_', **capargs))
+            caplines.extend(self.plot(x, upper, '_', **capargs))            
 
-            vl = self.vlines(x, y, upper)
-            for line in vl: line.set_color(ecolor)
-            l.extend( vl )
-
-            # bar caps
-            for xval, uval, lval in zip(x, upper, lower):
-                l1 = get_ybar_cap(xval, uval) 
-                l2 = get_ybar_cap(xval, lval) 
-                self.add_line(l1)
-                self.add_line(l2)
-                l.extend( (l1,l2) )
+        for l in barlines:
+            l.set_color(ecolor)
 
         self.autoscale_view()
 
-        return (l0, l)
-
+        return (l0, caplines+barlines)
 
     def fill(self, *args, **kwargs):
         """
@@ -1062,7 +1026,7 @@ The following kwargs are allowed:
 
     """
         if not self._hold: self.cla()
-        if alpha==1: self._images = []
+        #if alpha==1: self._images = []
 
         if norm is not None: assert(isinstance(norm, normalize))
         if cmap is not None: assert(isinstance(cmap, Colormap))        
@@ -1075,10 +1039,25 @@ The following kwargs are allowed:
         im.set_alpha(alpha)
 
         xmin, xmax, ymin, ymax = im.get_extent()
+        if interpolation!='nearest':
+            # set the extent to ignore edge effects
+            numrows, numcols = im.get_size()
+            width = abs(xmax-xmin)
+            height = abs(ymax-ymin)
+            xmax = xmin+(numcols-1.0)/numcols*width
+            if origin=='lower':
+                ymax = ymin+(numrows-1.0)/numrows*height
+            else:
+                ymin = ymax-(numrows-1.0)/numrows*height
+            # set the lim to the points where we have interp data w/o artifact
+
+
         corners = (xmin, ymin), (xmax, ymax)
         self.update_datalim(corners)
+        self.set_xlim((xmin, xmax))
+        self.set_ylim((ymin, ymax))                
         self._images.append(im)
-        self.autoscale_view()
+        
         return im
         
     def in_axes(self, xwin, ywin):
@@ -1213,10 +1192,28 @@ The following kwargs are allowed:
         Make a loglog plot with log scaling on the a and y axis.  The args
         to semilog x are the same as the args to plot.  See help plot for
         more info
+
+        Optional keyword args supported are any of the kwargs
+        supported by plot or set_xscale or set_yscale.  Notable, for
+        log scaling:
+
+        basex: base of the x logarithm
+        subsx: the location of the minor ticks; None defaults to range(2,basex)
+        basey: base of the y logarithm
+        subsy: the location of the minor yticks; None defaults to range(2,basey)
+
+        
         """
         if not self._hold: self.cla()
-        self.set_xscale('log')
-        self.set_yscale('log')
+        dx = {'basex': kwargs.get('basex', 10),
+              'subsx': kwargs.get('subsx', None),
+              }
+        dy = {'basey': kwargs.get('basey', 10),
+              'subsy': kwargs.get('subsy', None),
+              }
+
+        self.set_xscale('log', **dx)
+        self.set_yscale('log', **dy)
         l = self.plot(*args, **kwargs)
         return l
 
@@ -1314,12 +1311,14 @@ numcols of Z
 
         patches = []
 
-        verts =  [ ( (X[i,j], Y[i,j]),     (X[i,j], Y[i+1,j]),
-                     (X[i,j+1], Y[i+1,j]), (X[i,j+1], Y[i,j]))
+
+        verts =  [ ( (X[i,j], Y[i,j]),     (X[i+1,j], Y[i+1,j]),
+                     (X[i+1,j+1], Y[i+1,j+1]), (X[i,j+1], Y[i,j+1]))
                    for i in range(Nx-1)   for j in range(Ny-1)]
 
-        C = array([C[i,j] for i in range(Nx-1)  for j in range(Ny-1)])
 
+        C = array([C[i,j] for i in range(Nx-1)  for j in range(Ny-1)])
+        
         if shading == 'faceted':
             edgecolors =  (0,0,0,1), 
         else:
@@ -1481,20 +1480,79 @@ numcols of Z
 
     def plot(self, *args, **kwargs):
         """
-        Emulate matlab's plot command.  *args is a variable length
-        argument, allowing for multiple x,y pairs with an optional
-        format string.  For example, all of the following are legal,
-        assuming a is the Axis instance:
+Emulate matlab's plot command.  *args is a variable length
+argument, allowing for multiple x,y pairs with an optional
+format string.  For example, all of the following are legal,
+assuming a is the Axis instance:
         
-          a.plot(x,y)            # plot Numeric arrays y vs x
-          a.plot(x,y, 'bo')      # plot Numeric arrays y vs x with blue circles
-          a.plot(y)              # plot y using x as index array 0..N-1
-          a.plot(y, 'r+')        # ditto with red plusses
+    a.plot(x,y)            # plot Numeric arrays y vs x
+    a.plot(x,y, 'bo')      # plot Numeric arrays y vs x with blue circles
+    a.plot(y)              # plot y using x as index array 0..N-1
+    a.plot(y, 'r+')        # ditto with red plusses
 
-        An arbitrary number of x, y, fmt groups can be specified, as in 
-          a.plot(x1, y1, 'g^', x2, y2, 'l-')  
+An arbitrary number of x, y, fmt groups can be specified, as in 
 
-        Returns a list of lines that were added
+    a.plot(x1, y1, 'g^', x2, y2, 'g-')  
+
+Return value is a list of lines that were added
+
+The following line styles are supported:
+
+    -  : solid line
+    -- : dashed line
+    -. : dash-dot line
+    :  : dotted line
+    .  : points
+    ,  : pixels
+    o  : circle symbols
+    ^  : triangle up symbols
+    v  : triangle down symbols
+    <  : triangle left symbols
+    >  : triangle right symbols
+    s  : square symbols
+    +  : plus symbols
+    x  : cross symbols
+    D  : diamond symbols
+    d  : thin diamond symbols
+    1  : tripod down symbols
+    2  : tripod up symbols
+    3  : tripod left symbols
+    4  : tripod right symbols
+    h  : hexagon symbols
+    H  : rotated hexagon symbols
+    p  : pentagon symbols
+    |  : vertical line symbols
+    _  : horizontal line symbols
+
+The following color strings are supported
+
+    b  : blue
+    g  : green
+    r  : red
+    c  : cyan
+    m  : magenta
+    y  : yellow
+    k  : black 
+    w  : white
+
+Line styles and colors are combined in a single format string
+
+The kwargs that are can be used to set line properties (any property
+that has a set_* method).  You can use this to set a line label (for
+auto legends), linewidth, anitialising, marker face color, etc.  Here
+is an example:
+
+    plot([1,2,3], [1,2,3], 'go-', label='line 1', linewidth=2)
+    plot([1,2,3], [1,4,9], 'rs',  label='line 2')
+    axis([0, 4, 0, 10])
+    legend()
+
+If you make multiple lines with one plot command, the kwargs apply
+to all those lines, eg
+
+    plot(x1, y1, x2, y2, antialising=False)
+
+Neither line will be antialiased.
         """
 
         if not self._hold: self.cla()
@@ -1506,7 +1564,7 @@ numcols of Z
         self.autoscale_view()
         return lines
 
-    def plot_date(self, d, y, converter, fmt='bo', **kwargs):
+    def plot_date(self, d, y, converter=None, fmt='bo', **kwargs):
         """
         plot_date(d, y, converter, fmt='bo', **kwargs)
 
@@ -1565,6 +1623,7 @@ numcols of Z
         self.xaxis.set_major_locator(locator)
         self.xaxis.set_major_formatter(formatter)
         self.autoscale_view()
+
         return ret
         
     def psd(self, x, NFFT=256, Fs=2, detrend=mlab.detrend_none,
@@ -1834,11 +1893,23 @@ on be used if c is an array of floats
 
     def semilogx(self, *args, **kwargs):
         """
-        Make a semilog plot with log scaling on the x axis.  The args to
-        semilog x are the same as the args to plot.  See help plot for
-        more info    
+        Make a semilog plot with log scaling on the x axis.  The args
+        to semilog x are the same as the args to plot.  See help plot
+        for more info.
+
+        Optional keyword args supported are any of the kwargs
+        supported by plot or set_xscale.  Notable, for log scaling:
+
+        basex: base of the logarithm
+        subsx: the location of the minor ticks; None defaults to range(2,basex)
+
         """
-        self.set_xscale('log')
+
+        d = {'basex': kwargs.get('basex', 10),
+             'subsx': kwargs.get('subsx', None),
+             }
+             
+        self.set_xscale('log', **d)
         l = self.plot(*args, **kwargs)
         return l
 
@@ -1846,10 +1917,21 @@ on be used if c is an array of floats
     def semilogy(self, *args, **kwargs):
         """
         Make a semilog plot with log scaling on the y axis.  The args to
-        semilog x are the same as the args to plot.  See help plot for
-        more info    
+        semilogy are the same as the args to plot.  See help plot for
+        more info.
+
+        Optional keyword args supported are any of the kwargs
+        supported by plot or set_yscale.  Notable, for log scaling:
+
+        basey: base of the logarithm
+        subsy: the location of the minor ticks; None defaults to range(2,basey)
+        
         """
-        self.set_yscale('log')
+        d = {'basey': kwargs.get('basey', 10),
+             'subsy': kwargs.get('subsy', None),
+             }
+
+        self.set_yscale('log', **d)
         l = self.plot(*args, **kwargs)
         return l
 
@@ -1867,7 +1949,7 @@ on be used if c is an array of floats
 
         """
         override = {
-            'fontproperties': FontProperties(size=rcParams['axes.titlesize']),
+            'fontsize':rcParams['axes.titlesize'],
             'verticalalignment' : 'bottom',
             'horizontalalignment' : 'left'
             }
@@ -1912,12 +1994,24 @@ on be used if c is an array of floats
         if emit: self._send_xlim_event()
 
         
-    def set_xscale(self, value):
+    def set_xscale(self, value, basex = 10, subsx=None):
+        """
+        Set the xscaling: 'log' or 'linear'
+
+        if value is 'log', the additional kwargs have the following meaning
+
+        basex: base of the logarithm
+        subsx: the location of the minor ticks; None defaults to range(2,basex)
+
+        """
+
+        if subsx is None: subsx = range(2, basex)
         assert(value.lower() in ('log', 'linear', ))
         self._xscale = value
         if value == 'log':
-            self.xaxis.set_major_locator(LogLocator())
-            self.xaxis.set_major_formatter(LogFormatter())
+            self.xaxis.set_major_locator(LogLocator(basex))
+            self.xaxis.set_major_formatter(LogFormatterMathtext(basex))
+            self.xaxis.set_minor_locator(LogLocator(basex,subsx))
             self.transData.get_funcx().set_type(LOG10)
         elif value == 'linear':
             self.xaxis.set_major_locator(AutoLocator())
@@ -1944,7 +2038,6 @@ on be used if c is an array of floats
         Defaults override is
 
             override = {
-               'fontproperties'      : see FontProperties()
                'verticalalignment'   : 'center',
                'horizontalalignment' : 'right',
                'rotation'='vertical' : }
@@ -1967,17 +2060,30 @@ on be used if c is an array of floats
         self.viewLim.intervaly().set_bounds(*v)
         if emit: self._send_ylim_event()
         
-    def set_yscale(self, value):
+    def set_yscale(self, value, basey=10, subsy=None):
+        """
+        Set the yscaling: 'log' or 'linear'
+
+        if value is 'log', the additional kwargs have the following meaning
+
+        basey: base of the logarithm
+
+        subsy: the location of the minor ticks; None are the default range(2,basex)
+
+        """
+
+        if subsy is None: subsy = range(2, basey)
         assert(value.lower() in ('log', 'linear', ))
         self._yscale = value
         if value == 'log':
-            self.yaxis.set_major_locator(LogLocator())
-            self.yaxis.set_major_formatter(LogFormatter())
+            self.yaxis.set_major_locator(LogLocator(basey))
+            self.yaxis.set_major_formatter(LogFormatterMathtext(basey))
+            self.yaxis.set_minor_locator(LogLocator(basey,subsy))
             self.transData.get_funcy().set_type(LOG10)
         elif value == 'linear':
             self.yaxis.set_major_locator(AutoLocator())
             self.yaxis.set_major_formatter(ScalarFormatter())
-            self.transData.get_funcy().set_type(IDENTITY)
+            self.transData.get_funcy().set_type( IDENTITY )
 
             
 
@@ -2140,14 +2246,13 @@ on be used if c is an array of floats
 
         If len(args) the override dictionary will be:
 
-          'fontproperties'      : see FontProperties
           'verticalalignment'   : 'bottom',
           'horizontalalignment' : 'left'
-
+          'transform'           : self.transData
 
         **kwargs can in turn be used to override the override, as in
 
-          a.text(x,y,label, fontpropeties=FontProperties(size=12))
+          a.text(x,y,label, fontsize=12)
         
         will have verticalalignment=bottom and
         horizontalalignment=left but will have a fontsize of 12
@@ -2176,11 +2281,9 @@ on be used if c is an array of floats
 
         """
         override = {
-            'fontproperties': FontProperties(),
             'verticalalignment' : 'bottom',
             'horizontalalignment' : 'left',
             #'verticalalignment' : 'top',            
-            #'fontsize' : 'small',
             'transform' : self.transData,
             }
 
@@ -2189,9 +2292,11 @@ on be used if c is an array of floats
             x=x, y=y, text=text,
             )
         self._set_artist_props(t)
+
         t.update_properties(override)
         self._text.append(t)
-        t.set_clip_box(self.bbox)
+
+        if t.get_clip_on():  t.set_clip_box(self.bbox)
         return t
     
 
