@@ -308,6 +308,12 @@ class RendererBase:
         """
         pass # derived must override
 
+    def strip_math(self, s):
+        remove = (r'\rm', '\cal', '\tt', '\it', '\\', '{', '}')
+        s = s[1:-1]
+        for r in remove:  s = s.replace(r,'')
+        return s
+    
     def draw_text(self, gc, x, y, s, prop, angle, ismath=False):
         """
         Draw string s at x,y (display coords) with font properties
@@ -600,8 +606,11 @@ class FigureCanvasBase:
         pass
         
     def mpl_disconnect(self, cid):
-        'Connect s to func. return an id that can be used with disconnect'
-        pass
+        """
+        Connect s to func. return an id that can be used with disconnect
+        Method should return None
+        """
+        return None
 
 class FigureManagerBase:
     """
@@ -854,13 +863,13 @@ class NavigationToolbar2:
             self._active = 'PAN'
 
         if self._idPress is not None:
-            self.canvas.mpl_disconnect(self._idPress)
-            self._idPress=None
+            self._idPress = self.canvas.mpl_disconnect(self._idPress)
+
         if self._idRelease is not None:
-            self.canvas.mpl_disconnect(self._idRelease)
-            self._idPress=None
+            self._idRelease = self.canvas.mpl_disconnect(self._idRelease)
+
         if self._active:    
-            self._idPress   = self.canvas.mpl_connect(
+            self._idPress = self.canvas.mpl_connect(
                 'button_press_event', self.press_pan)
             self._idRelease = self.canvas.mpl_connect(
                 'button_release_event', self.release_pan)
@@ -1137,13 +1146,13 @@ class NavigationToolbar2:
             self._active = 'ZOOM'
 
         if self._idPress is not None:
-            self.canvas.mpl_disconnect(self._idPress)
-            self._idPress=None
+            self._idPress=self.canvas.mpl_disconnect(self._idPress)
+
         if self._idRelease is not None:
-            self.canvas.mpl_disconnect(self._idRelease)
-            self._idRelease=None
+            self._idRelease=self.canvas.mpl_disconnect(self._idRelease)
+
         if  self._active: 
-            self._idPress   = self.canvas.mpl_connect('button_press_event', self.press_zoom)
+            self._idPress = self.canvas.mpl_connect('button_press_event', self.press_zoom)
             self._idRelease = self.canvas.mpl_connect('button_release_event', self.release_zoom)
     
 def error_msg(msg, *args, **kwargs):
