@@ -67,8 +67,10 @@ def show():
     import matplotlib
     matplotlib.interactive(True)
     #os.environ['PYTHONINSPECT'] = '1'
-    Tk.mainloop()
-
+    if show._needmain:
+        Tk.mainloop()
+        show._needmain = False
+show._needmain = True
 
 def new_figure_manager(num, *args, **kwargs):
     """
@@ -234,7 +236,8 @@ class FigureCanvasTkAgg(FigureCanvasAgg):
     def mpl_disconnect(self, cid):
         eventname, the_binding = cid
         self._tkcanvas.unbind(eventname) #, the_binding)
-
+        return None
+    
 class FigureManagerTkAgg(FigureManagerBase):
     """
     Public attributes
