@@ -137,7 +137,8 @@ import os, sys
 from cStringIO import StringIO
 
 from matplotlib.pyparsing import Literal, Word, OneOrMore, ZeroOrMore, \
-     Combine, Group, Optional, Forward, NotAny, alphas, nums, alphanums
+     Combine, Group, Optional, Forward, NotAny, alphas, nums, alphanums, \
+     StringStart, StringEnd, ParseException
 
 from matplotlib.afm import AFM
 from matplotlib.cbook import True, False, enumerate, iterable, Bunch
@@ -197,7 +198,23 @@ class Fonts:
 
     def render(self, ox, oy, font, sym, fontsize, dpi):
         pass
-        
+
+
+class DummyFonts:
+    'dummy class for debugging parser'
+    def get_metrics(self, font, sym, fontsize, dpi):
+
+        metrics = Bunch(
+            advance  = 0,
+            height   = 0,
+            width    = 0,
+            xmin = 0,
+            xmax = 0,
+            ymin = 0,
+            ymax = 0,
+            )
+        return metrics
+
 class BakomaTrueTypeFonts(Fonts):
     """
     Use the Bakoma true type fonts for rendering
@@ -695,11 +712,11 @@ class Handler:
         return loc, [element]
 
     def symbol(self, s, loc, toks):
-
+        #print 'symbol', s, toks
         assert(len(toks)==1)
 
         s  = toks[0]
-        #print 'sym', toks[0]
+        #~ print 'sym', toks[0]
         if charOverChars.has_key(s):
             under, over, pad = charOverChars[s]
             font, tok, scale = under
@@ -828,7 +845,8 @@ misc = exclamation | at | percent | ampersand
 
 over = Literal('over')
 under = Literal('under')
-composite = over | under
+#~ composite = over | under
+overUnder = over | under
 
 
 
@@ -853,7 +871,8 @@ char = Word(alphanums + ' ', exact=1).leaveWhitespace()
 
 space = (Literal(r'\ ') | Literal(r'\/') | Group(Literal(r'\hspace{') + number + Literal('}'))).setParseAction(handler.space).setName('space')
 
-symbol = (texsym ^ char ^ binop ^ relation ^ punctuation ^ misc ^ grouping  ).setParseAction(handler.symbol).leaveWhitespace()
+#~ symbol = (texsym ^ char ^ binop ^ relation ^ punctuation ^ misc ^ grouping  ).setParseAction(handler.symbol).leaveWhitespace()
+symbol = (texsym | char | binop | relation | punctuation | misc | grouping  ).setParseAction(handler.symbol).leaveWhitespace()
 
 subscript = Forward().setParseAction(handler.subscript).setName("subscript")
 superscript = Forward().setParseAction(handler.superscript).setName("superscript")
@@ -861,13 +880,16 @@ subsuperscript = Forward().setParseAction(handler.subsuperscript).setName("subsu
 
 
 group = Group( lbrace + OneOrMore(symbol^subscript^superscript^subsuperscript^space) + rbrace).setParseAction(handler.group).setName("group")
+#~ group = Group( lbrace + OneOrMore(subsuperscript | subscript | superscript | symbol | space ) + rbrace).setParseAction(handler.group).setName("group")
 
 #composite = Group( Combine(bslash + composite) + lbrace + symbol + rbrace + lbrace + symbol + rbrace).setParseAction(handler.composite).setName("composite")
-composite = Group( Combine(bslash + composite) + group + group).setParseAction(handler.composite).setName("composite")
+#~ composite = Group( Combine(bslash + composite) + group + group).setParseAction(handler.composite).setName("composite")
+composite = Group( Combine(bslash + overUnder) + group + group).setParseAction(handler.composite).setName("composite")
 
 
 
-symgroup = symbol ^ group
+#~ symgroup = symbol ^ group
+symgroup = symbol | group
 
 subscript << Group( symgroup + Literal('_') + symgroup  )
 superscript << Group( symgroup + Literal('^') + symgroup  )
@@ -878,11 +900,14 @@ font = Group( Combine(bslash + fontname) + group).setParseAction(handler.font).s
 
 expression = OneOrMore(
     space ^ font ^ symbol ^ subscript ^ superscript ^ subsuperscript ^ group ^ composite ).setParseAction(handler.expression).setName("expression")
+#~ expression = OneOrMore(
+    #~ group | composite | space | font | subsuperscript | subscript | superscript | symbol ).setParseAction(handler.expression).setName("expression")
 
 ####
 
 
 
+
 def math_parse_s_ft2font(s, dpi, fontsize, angle=0):
     """
     Parse the math expression s, return the (bbox, fonts) tuple needed
@@ -892,6 +917,11 @@ def math_parse_s_ft2font(s, dpi, fontsize, angle=0):
 
     return is width, height, fonts
     """
+
+    major, minor1, minor2, tmp, tmp = sys.version_info
+    if major==2 and minor1==2:
+        print >> sys.stderr, 'mathtext broken on python2.2.  We hope to get this fixed soon'
+        sys.exit()
     cacheKey = (s, dpi, fontsize, angle)
     s = s[1:-1]  # strip the $ from front and back
     if math_parse_s_ft2font.cache.has_key(cacheKey):
@@ -978,37 +1008,47 @@ def math_parse_s_ps(s, dpi, fontsize):
 
 math_parse_s_ps.cache = {}
 
-
-if __name__=='__main__':
+if __name__=='___main__':
     
-    s = r'$dz/dt \/ = \/ \gamma x^2 \/ + \/ \rm{sin}(2\pi y+\phi)$'
-    #s = r'$x^1 2$'
-    #s = r'$\alpha_{i+1}^j \/ = \/ \rm{sin}(2\pi f_j t_i) e^{-5 t_i/\tau}$'
-    #s = r'$\cal{R}\prod_{i=\alpha_{i+1}}^\infty a_i\rm{sin}(2 \pi f x_i)$'
-    #s = r'$\bigodot \bigoplus \cal{R} a_i\rm{sin}(2 \pi f x_i)$'
-    #s = r'$x_i$'
-    #s = r'$5\/\angstrom\hspace{ 2.0 }\pi$'
-    #s = r'$x+1$'
-    w, h, fonts = math_parse_s_ft2font(s, 20, 72)
+    stests = [ 
+            r'$dz/dt \/ = \/ \gamma x^2 \/ + \/ \rm{sin}(2\pi y+\phi)$',
+            r'$dz/dt \/ = \/ \gamma xy^2 \/ + \/ \rm{s}(2\pi y+\phi)$',
+            r'$x^1 2$',
+            r'$\alpha_{i+1}^j \/ = \/ \rm{sin}(2\pi f_j t_i) e^{-5 t_i/\tau}$',
+            r'$\cal{R}\prod_{i=\alpha_{i+1}}^\infty a_i\rm{sin}(2 \pi f x_i)$',
+            r'$\bigodot \bigoplus \cal{R} a_i\rm{sin}(2 \pi f x_i)$',
+            r'$x_i$',
+            r'$5\/\angstrom\hspace{ 2.0 }\pi$',
+            r'$x+1$',
+            r'$i$',
+            r'$i^j$',
+            ]
+    #~ w, h, fonts = math_parse_s_ft2font(s, 20, 72)
+    for s in stests:
+        try:
+            print s
+            print (expression + StringEnd()).parseString( s[1:-1] )
+        except ParseException, pe:
+            print "*** ERROR ***", pe.msg
+            print s
+            print 'X' + (' '*pe.loc)+'^'
+            # how far did we get?
+            print expression.parseString( s[1:-1] )
+        print
 
     #w, h, fonts = math_parse_s_ps(s, 20, 72)
 
 
-    if 0:  # ft2font
-        from matplotlib.backend_bases import GraphicsContextBase
-        from matplotlib.backends._backend_agg import RendererAgg
+if __name__=='__main__':
+    s = 'i'
 
-        gc = GraphicsContextBase()
-        width, height = 600, 600
-        renderer = RendererAgg(width, height, 72)
+    Element.fonts = DummyFonts()
+    handler.clear()
+    expression.parseString( s )
 
-        for font in Element.fonts.fonts.values():
-            renderer.draw_text( font, 20, 200, (0,0,0,1))
-            renderer.draw_rectangle(gc, None, 20, height-200, w, h)
-
-
-        import Image
-        s = renderer.tostring_rgb()
-        im = Image.fromstring( "RGB", (width,height), s)
-        im.show()
+    handler.expr.set_size_info(12, 72)
 
+    # set the origin once to allow w, h compution
+    handler.expr.set_origin(0, 0)
+    for e in handler.symbols:
+        assert(hasattr(e, 'metrics'))
