@@ -110,7 +110,7 @@ def detrend_linear(x):
     # I'm going to regress x on xx=range(len(x)) and return x -
     # (b*xx+a).  Now that I have polyfit working, I could convert the
     # code here, but if it ain't broke, don't fix it!
-    xx = arange(len(x), x.typecode())
+    xx = arange(float(len(x)))
     X = transpose(array([xx]+[x]))
     C = cov(X)
     b = C[0,1]/C[0,0]
